]> andersk Git - openssh.git/blobdiff - packet.h
- stevesk@cvs.openbsd.org 2001/04/14 16:33:20
[openssh.git] / packet.h
index 597fbb1514b4b5fe21862be63120c220b004376d..0f5e710499797c2641730bf458a83d660588b639 100644 (file)
--- a/packet.h
+++ b/packet.h
@@ -11,7 +11,7 @@
  * called by a name other than "ssh" or "Secure Shell".
  */
 
-/* RCSID("$OpenBSD: packet.h,v 1.18 2000/12/19 23:17:57 markus Exp $"); */
+/* RCSID("$OpenBSD: packet.h,v 1.22 2001/04/14 16:33:20 stevesk Exp $"); */
 
 #ifndef PACKET_H
 #define PACKET_H
@@ -65,7 +65,7 @@ void    packet_start_compression(int level);
  * Informs that the current session is interactive.  Sets IP flags for
  * optimal performance in interactive use.
  */
-void    packet_set_interactive(int interactive, int keepalives);
+void    packet_set_interactive(int interactive);
 
 /* Returns true if the current connection is interactive. */
 int     packet_is_interactive(void);
@@ -178,8 +178,8 @@ extern int max_packet_size;
 int     packet_set_maxsize(int s);
 #define packet_get_maxsize() max_packet_size
 
-/* Stores tty modes from the fd into current packet. */
-void    tty_make_modes(int fd);
+/* Stores tty modes from the fd or tiop into current packet. */
+void    tty_make_modes(int fd, struct termios *tiop);
 
 /* Parses tty modes for the fd from the current packet. */
 void    tty_parse_modes(int fd, int *n_bytes_ptr);
@@ -214,4 +214,10 @@ void       packet_set_ssh2_format(void);
 /* returns remaining payload bytes */
 int    packet_remaining(void);
 
+/* append an ignore message */
+void   packet_send_ignore(int nbytes);
+
+/* add an ignore message and make sure size (current+ignore) = n*sumlen */
+void   packet_inject_ignore(int sumlen);
+
 #endif                         /* PACKET_H */
This page took 0.035772 seconds and 4 git commands to generate.